********
Jasmine
********

For front-end unit testing it's used Jasmine framework.

Installation
============

Please apply one of the following instructions.

Docker
------
#. Use `Docker Readme </docker>`_ to prepare Docker

Local
-----
#. Install `Nodejs <https://nodejs.org/en/download/package-manager/>`_

Requirements
============
- `Karma <https://karma-runner.github.io>`_
- `Jasmine <https://jasmine.github.io/>`_
- `Docker <https://www.docker.com/>`_

Running
=======

Docker
------
To run tests inside Docker container please follow instructions in `Docker Readme </docker#run-tests>`_

Local
-----
To run tests locally please execute command ``npm test``.
